bug-gnulib
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH 09/11] signal_h: Fix Android build


From: Kevin Cernekee
Subject: [PATCH 09/11] signal_h: Fix Android build
Date: Wed, 11 Feb 2015 15:22:57 -0800

* lib/signal.in.h: Add Android to the list of platforms that declare
pthread_sigmask() in <pthread.h> instead of <signal.h>.
---
 ChangeLog       | 4 ++++
 lib/signal.in.h | 8 +++++---
 2 files changed, 9 insertions(+), 3 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index d17b2220125b..6ed3de23809f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -46,6 +46,10 @@
        * m4/net_if_h.m4: Check to make sure <net/if.h> actually defines
        struct if_nameindex.  If not, enable the replacement header.
 
+       signal_h: Fix Android build
+       * lib/signal.in.h: Add Android to the list of platforms that declare
+       pthread_sigmask() in <pthread.h> instead of <signal.h>.
+
 2015-02-08  Daiki Ueno  <address@hidden>
 
        uniname/unimame-tests: don't link with -lunistring
diff --git a/lib/signal.in.h b/lib/signal.in.h
index 0f2ff5af8435..265b72ab0ec5 100644
--- a/lib/signal.in.h
+++ b/lib/signal.in.h
@@ -55,11 +55,13 @@
 #ifndef address@hidden@_SIGNAL_H
 #define address@hidden@_SIGNAL_H
 
-/* Mac OS X 10.3, FreeBSD 6.4, OpenBSD 3.8, OSF/1 4.0, Solaris 2.6 declare
-   pthread_sigmask in <pthread.h>, not in <signal.h>.
+/* Mac OS X 10.3, FreeBSD 6.4, OpenBSD 3.8, OSF/1 4.0, Solaris 2.6, Android
+   declare pthread_sigmask in <pthread.h>, not in <signal.h>.
    But avoid namespace pollution on glibc systems.*/
 #if (@GNULIB_PTHREAD_SIGMASK@ || defined GNULIB_POSIXCHECK) \
-    && ((defined __APPLE__ && defined __MACH__) || defined __FreeBSD__ || 
defined __OpenBSD__ || defined __osf__ || defined __sun) \
+    && ((defined __APPLE__ && defined __MACH__) \
+        || defined __FreeBSD__ || defined __OpenBSD__ || defined __osf__ \
+        || defined __sun || defined __ANDROID__) \
     && ! defined __GLIBC__
 # include <pthread.h>
 #endif
-- 
2.2.0.rc0.207.ga3a616c




reply via email to

[Prev in Thread] Current Thread [Next in Thread]